==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/RiskEventSubject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.RiskEventSubjectRiskLevel;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * RiskEventSubject
 */
@JsonPropertyOrder({ RiskEventSubject.JSON_PROPERTY_IP, RiskEventSubject.JSON_PROPERTY_MESSAGE,
        RiskEventSubject.JSON_PROPERTY_RISK_LEVEL })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class RiskEventSubject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_IP = "ip";
    private String ip;

    public static final String JSON_PROPERTY_MESSAGE = "message";
    private String message;

    public static final String JSON_PROPERTY_RISK_LEVEL = "riskLevel";
    private RiskEventSubjectRiskLevel riskLevel;

    public RiskEventSubject() {
    }

    public RiskEventSubject ip(String ip) {

        this.ip = ip;
        return this;
    }

    /**
     * The risk event subject IP address (either an IPv4 or IPv6 address)
     *
     * @return ip
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "The risk event subject IP address (either an IPv4 or IPv6 address)")
    @JsonProperty(JSON_PROPERTY_IP)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getIp() {
        return ip;
    }

    @JsonProperty(JSON_PROPERTY_IP)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setIp(String ip) {
        this.ip = ip;
    }

    public RiskEventSubject message(String message) {

        this.message = message;
        return this;
    }

    /**
     * Additional reasons for the risk level of the IP
     *
     * @return message
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Additional reasons for the risk level of the IP")
    @JsonProperty(JSON_PROPERTY_MESSAGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getMessage() {
        return message;
    }

    @JsonProperty(JSON_PROPERTY_MESSAGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMessage(String message) {
        this.message = message;
    }

    public RiskEventSubject riskLevel(RiskEventSubjectRiskLevel riskLevel) {

        this.riskLevel = riskLevel;
        return this;
    }

    /**
     * Get riskLevel
     *
     * @return riskLevel
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_RISK_LEVEL)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public RiskEventSubjectRiskLevel getRiskLevel() {
        return riskLevel;
    }

    @JsonProperty(JSON_PROPERTY_RISK_LEVEL)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setRiskLevel(RiskEventSubjectRiskLevel riskLevel) {
        this.riskLevel = riskLevel;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RiskEventSubject riskEventSubject = (RiskEventSubject) o;
        return Objects.equals(this.ip, riskEventSubject.ip) && Objects.equals(this.message, riskEventSubject.message)
                && Objects.equals(this.riskLevel, riskEventSubject.riskLevel);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(ip, message, riskLevel);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RiskEventSubject {\n");
        sb.append("    ip: ").append(toIndentedString(ip)).append("\n");
        sb.append("    message: ").append(toIndentedString(message)).append("\n");
        sb.append("    riskLevel: ").append(toIndentedString(riskLevel)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/RiskEventSubject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.RiskEventSubjectRiskLevel;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * RiskEventSubject
 */
@JsonPropertyOrder({ RiskEventSubject.JSON_PROPERTY_IP, RiskEventSubject.JSON_PROPERTY_MESSAGE,
        RiskEventSubject.JSON_PROPERTY_RISK_LEVEL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class RiskEventSubject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_IP = "ip";
    private String ip;

    public static final String JSON_PROPERTY_MESSAGE = "message";
    private String message;

    public static final String JSON_PROPERTY_RISK_LEVEL = "riskLevel";
    private RiskEventSubjectRiskLevel riskLevel;

    public RiskEventSubject() {
    }

    public RiskEventSubject ip(String ip) {

        this.ip = ip;
        return this;
    }

    /**
     * The risk event subject IP address (either an IPv4 or IPv6 address)
     *
     * @return ip
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "The risk event subject IP address (either an IPv4 or IPv6 address)")
    @JsonProperty(JSON_PROPERTY_IP)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public String getIp() {
        return ip;
    }

    @JsonProperty(JSON_PROPERTY_IP)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setIp(String ip) {
        this.ip = ip;
    }

    public RiskEventSubject message(String message) {

        this.message = message;
        return this;
    }

    /**
     * Additional reasons for the risk level of the IP
     *
     * @return message
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Additional reasons for the risk level of the IP")
    @JsonProperty(JSON_PROPERTY_MESSAGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getMessage() {
        return message;
    }

    @JsonProperty(JSON_PROPERTY_MESSAGE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMessage(String message) {
        this.message = message;
    }

    public RiskEventSubject riskLevel(RiskEventSubjectRiskLevel riskLevel) {

        this.riskLevel = riskLevel;
        return this;
    }

    /**
     * Get riskLevel
     *
     * @return riskLevel
     **/
    @javax.annotation.Nonnull
    @ApiModelProperty(required = true, value = "")
    @JsonProperty(JSON_PROPERTY_RISK_LEVEL)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)

    public RiskEventSubjectRiskLevel getRiskLevel() {
        return riskLevel;
    }

    @JsonProperty(JSON_PROPERTY_RISK_LEVEL)
    @JsonInclude(value = JsonInclude.Include.ALWAYS)
    public void setRiskLevel(RiskEventSubjectRiskLevel riskLevel) {
        this.riskLevel = riskLevel;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        RiskEventSubject riskEventSubject = (RiskEventSubject) o;
        return Objects.equals(this.ip, riskEventSubject.ip) && Objects.equals(this.message, riskEventSubject.message)
                && Objects.equals(this.riskLevel, riskEventSubject.riskLevel);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(ip, message, riskLevel);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class RiskEventSubject {\n");
        sb.append("    ip: ").append(toIndentedString(ip)).append("\n");
        sb.append("    message: ").append(toIndentedString(message)).append("\n");
        sb.append("    riskLevel: ").append(toIndentedString(riskLevel)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
